%% l = logsum(x)
% calculates the sum of the column vectors, under the assumption that
% all values are in logarithmic representation. It avoids numerical
% instability and uses fast matrix operations. It does do quite a bit of
% floating point processing though.
%
% Input:
% x: a matrix of values in logarithmic representation
%
% Output:
% l: a row vector containing the sums of the column vectors in logarithmic
%    representation.
%
function l = logsum(x)
  m = max(x, [], 1);
  l = log(sum(exp(bsxfun(@minus,x,m))))+m;
end
