%% [mu, s2] = mypolyval(coef, A, x)
% Evaluates the Bayesian predictive distribution for a polynomial model
% with Jeffreys' prior, fitted using mypolyfit. Since it is Gaussian, it
% can be returned in the form of mean and variance.

% Input:
% coef: the coefficients of the polynomial
% A: intermediate value produced by mypolyfit
% x: the x values at which to evaluate the polynomial
%
% Output:
% mu: the mean of the predictive distribution at each x point
% s2: the variance of the predictive distribution at each x point.
%
function [mu, s2] = mypolyval(coef, A, x)
  X = vandermonde(x, length(coef)-1);
  mu = X*coef;               % equivalent to polyval(F.coef', x);
  s2 = 1+dot(X, X*A, 2);     % equivalent to diag(X*A*X')
end
